precision highp float;

uniform sampler2D u_Texture;
varying vec2 v_TexCoord;
uniform float iTime;
uniform float iZoom;
uniform float iUsePinLocation;
uniform vec2 iResolution;
uniform vec2 iPin;
uniform vec4 iRect1;

#define SCALE 25.0 * (iRect1.z - iRect1.w) / iResolution.x * iZoom
#define SPEED 0.7
#define FREQUENCY -.1

float d;
// Circle
#define C(p, o)  min(1., sqrt(10.*abs(length((p-.5)/(o + .001))-.4)))
// Little dot
#define D(p,o)  ( (d=length(p-o)*5.)<=.6 ? d:1. )

vec3 ramp(float t) {
	return t <= .5 ? vec3( 1. - t * 1.4, .2, 1.05 ) / t : vec3( .3 * (1. - t) * 2., .2, 1.05 ) / t;
}

void main()
{
    gl_FragColor = texture2D(u_Texture, v_TexCoord);

    // All the countries borders, apply a glowing effect
    if (gl_FragColor.r >= 0.25 &&
        gl_FragColor.g >= 0.25 &&
        gl_FragColor.b >= 0.25 &&
        gl_FragColor.a >= 0.25) {

        float eval = (SPEED * iTime * 2.0);

        float radius = 0.57255;
        vec2 center = vec2(1.0, -0.25);

        vec2 diff = (min(center - (v_TexCoord * (eval - (3.0 * floor(eval/3.0)))), 0.0));
        float len = length(diff);
        float width = 0.235;

        float r = 2.6;
        float omega = 0.5;
        vec3 col2 = vec3(r * (cos(omega  ) + 2.) / 2. - len, 0., 0.);
        gl_FragColor += vec4(col2, 1.0);
        gl_FragColor *= vec4(0.0, 1.0, 0.0, 1.0);

        float circle = smoothstep(radius-width, radius, len) - smoothstep(radius, radius+width, len);
        gl_FragColor *= vec4(vec3(circle), 1.0);

        vec3 mask = ramp(iTime * 50.0) + vec3(0.435, max(0.6, circle), 0.266);
        gl_FragColor += vec4(mask, 1.0);
        gl_FragColor *= vec4(min(0.435, gl_FragColor.x), min(0.737, gl_FragColor.y), min(0.266, gl_FragColor.z), 1.0);
    }
    // Selected country fill
    else if (gl_FragColor.rgb == vec3(0.0)) {

        // Selected country rect boundary edges
        // x=top, y=bottom, z=left, w=right
        vec2 rect1TopLeftCoord = vec2(iRect1.z, iRect1.x);
        vec2 rect1BottomLeftCoord = vec2(iRect1.z, iRect1.y);
        vec2 rect1BottomRightCoord = vec2(iRect1.w, iRect1.y);
        vec2 rect1TopRightCoord = vec2(iRect1.w, iRect1.x);

        float topLeft = (rect1TopLeftCoord.x / iResolution.x);
        float topRight = (rect1TopRightCoord.x / iResolution.x);
        float bottomLeft = (rect1TopLeftCoord.y / iResolution.y);
        float bottomRight = (rect1BottomRightCoord.y / iResolution.y);

        if (v_TexCoord.x >= topLeft &&
            v_TexCoord.x <= topRight &&
            v_TexCoord.y >= bottomLeft &&
            v_TexCoord.y <= bottomRight ){

            gl_FragColor = vec4(0.135, 0.135, 0.135, 1.0);
        } else {
            gl_FragColor.xyz = vec3(0.2);
        }
    }
}